==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/prop/BombItem.java <==
package cc.thonly.reverie_dreams.item.prop;

import cc.thonly.reverie_dreams.entity.misc.DanmakuEntity;
import cc.thonly.reverie_dreams.item.ModItems;
import cc.thonly.reverie_dreams.sound.SoundEventInit;
import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1297;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2392;
import net.minecraft.class_2398;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_3468;
import net.minecraft.class_5819;

public class BombItem extends class_1792 {
    public BombItem(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        if (!world.field_9236 && world instanceof class_3218 serverWorld) {
            class_1799 itemStack = user.method_5998(hand);
            world.method_43128(null, user.method_23317(), user.method_23320(), user.method_23321(), SoundEventInit.SPELL_CARD, user.method_5634(), 1.0f, 1.0f);
            List<class_1297> nearbyEntities = serverWorld.method_8390(class_1297.class, user.method_5829().method_1014(20), entity -> true);
            List<class_1297> nearbyDanmaku = nearbyEntities.stream().filter((entity -> entity instanceof DanmakuEntity danmakuEntity && danmakuEntity.method_24921() != user)).toList();
            List<class_1297> sign = new ArrayList<>();
            class_2392 ispe = new class_2392(class_2398.field_11218, ModItems.BOMB_FRAGMENT.method_7854());
            serverWorld.method_65096(
                    ispe,
                    user.method_23317(),
                    user.method_23318(),
                    user.method_23321(),
                    1,
                    0.25,
                    0.5,
                    0.25,
                    0.25
            );
            nearbyDanmaku.forEach((entity) -> {
                DanmakuEntity danmakuEntity = (DanmakuEntity) entity;
                class_243 pos = danmakuEntity.method_19538();
                int particleCount = (int) 8;
                double radius = danmakuEntity.method_17681() / 2 + 0.5;
                double heightOffset = danmakuEntity.method_17682();
                class_5819 random = world.method_8409();
                int count = random.method_39332(1, 4);
                for (int i = 0; i < count; i++) {
                    serverWorld.method_8649(
                            new class_1542(serverWorld,
                                    danmakuEntity.method_23317(),
                                    danmakuEntity.method_23318(),
                                    danmakuEntity.method_23321(),
                                    new class_1799(ModItems.POINT)
                            )
                    );
                }
                for (int i = 0; i < particleCount; i++) {
                    double angle = (2 * Math.PI / particleCount) * i;
                    double xOffset = radius * Math.cos(angle);
                    double zOffset = radius * Math.sin(angle);

                    class_2392 itemStackParticleEffect = new class_2392(class_2398.field_11218, ModItems.POINT.method_7854());
                    serverWorld.method_65096(
                            itemStackParticleEffect,
                            pos.field_1352,
                            pos.field_1351,
                            pos.field_1350,
                            1,
                            xOffset,
                            (heightOffset / particleCount) * i,
                            zOffset,
                            0.25
                    );
                }
                danmakuEntity.method_31472();
                sign.add(entity);
            });
            for (class_1297 entity : nearbyEntities) {
                if (sign.contains(entity)) {
                    continue;
                }
                if (entity.equals(user)) {
                    continue;
                }
                serverWorld.method_8649(
                        new class_1542(serverWorld,
                                user.method_23317(),
                                user.method_23318(),
                                user.method_23321(),
                                new class_1799(ModItems.POINT)
                        )
                );
            }
            user.method_7259(class_3468.field_15372.method_14956(this));
            itemStack.method_57008(1, user);
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }
}

==> reverie_dreams-0.4.8%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/prop/BombItem.java <==
package cc.thonly.reverie_dreams.item.prop;

import cc.thonly.reverie_dreams.entity.misc.DanmakuEntity;
import cc.thonly.reverie_dreams.registry.content.item.RDItems;
import cc.thonly.reverie_dreams.sound.SoundEventInit;
import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1297;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2392;
import net.minecraft.class_2398;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_3468;
import net.minecraft.class_5819;

public class BombItem extends class_1792 {
    public BombItem(class_1793 settings) {
        super(settings);
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        if (!world.field_9236 && world instanceof class_3218 serverWorld) {
            class_1799 itemStack = user.method_5998(hand);
            world.method_43128(null, user.method_23317(), user.method_23320(), user.method_23321(), SoundEventInit.SPELL_CARD, user.method_5634(), 1.0f, 1.0f);
            List<class_1297> nearbyEntities = serverWorld.method_8390(class_1297.class, user.method_5829().method_1014(20), entity -> true);
            List<class_1297> nearbyDanmaku = nearbyEntities.stream().filter((entity -> entity instanceof DanmakuEntity danmakuEntity && danmakuEntity.method_24921() != user)).toList();
            List<class_1297> sign = new ArrayList<>();
            class_2392 ispe = new class_2392(class_2398.field_11218, RDItems.BOMB_FRAGMENT.method_7854());
            serverWorld.method_65096(
                    ispe,
                    user.method_23317(),
                    user.method_23318(),
                    user.method_23321(),
                    1,
                    0.25,
                    0.5,
                    0.25,
                    0.25
            );
            nearbyDanmaku.forEach((entity) -> {
                DanmakuEntity danmakuEntity = (DanmakuEntity) entity;
                class_243 pos = danmakuEntity.method_19538();
                int particleCount = (int) 8;
                double radius = danmakuEntity.method_17681() / 2 + 0.5;
                double heightOffset = danmakuEntity.method_17682();
                class_5819 random = world.method_8409();
                int count = random.method_39332(1, 4);
                for (int i = 0; i < count; i++) {
                    serverWorld.method_8649(
                            new class_1542(serverWorld,
                                    danmakuEntity.method_23317(),
                                    danmakuEntity.method_23318(),
                                    danmakuEntity.method_23321(),
                                    new class_1799(RDItems.POINT)
                            )
                    );
                }
                for (int i = 0; i < particleCount; i++) {
                    double angle = (2 * Math.PI / particleCount) * i;
                    double xOffset = radius * Math.cos(angle);
                    double zOffset = radius * Math.sin(angle);

                    class_2392 itemStackParticleEffect = new class_2392(class_2398.field_11218, RDItems.POINT.method_7854());
                    serverWorld.method_65096(
                            itemStackParticleEffect,
                            pos.field_1352,
                            pos.field_1351,
                            pos.field_1350,
                            1,
                            xOffset,
                            (heightOffset / particleCount) * i,
                            zOffset,
                            0.25
                    );
                }
                danmakuEntity.method_31472();
                sign.add(entity);
            });
            for (class_1297 entity : nearbyEntities) {
                if (sign.contains(entity)) {
                    continue;
                }
                if (entity.equals(user)) {
                    continue;
                }
                serverWorld.method_8649(
                        new class_1542(serverWorld,
                                user.method_23317(),
                                user.method_23318(),
                                user.method_23321(),
                                new class_1799(RDItems.POINT)
                        )
                );
            }
            user.method_7259(class_3468.field_15372.method_14956(this));
            itemStack.method_57008(1, user);
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }
}
